# ggwp: Prepare Fast, Analyze Faster

## What is ggwp?

**ggwp** is a Python package for fast and easy data analytics.  
It aims to make a data model that can be applied for some use cases  
such as customer analytics. The data model created by ggwp is designed  
directly from my personal experiences, which will be more and more data models  
in the future.  

## Main Features  
Here are current features available in **ggwp**:  

-  DataModel: prepare your raw data for a general data model
-  EzCheck: check your data quality
-  EzRFM: create RFMT dataset
-  EzCohort: create Cohort dataset
-  EzCustomerMovement: create Customer Movement dataset
-  EzBasketEvolving: create Basket Evolving dataset
-  EzLog: log your data status and your remark, so you know what you've done for each stage

## Where to get **ggwp**  
The source code is currently hosted GitHub at:  
https://github.com/datanooblol/ggwp  

The latest version is available at  
[Python Package Index (PyPI)](https://pypi.org/project/ggwp/)  

```sh  
# pip  
pip install ggwp  
```  

## Dependencies  

-  NumPy  
-  pandas  